@@ -154,20 +154,12 @@ func NewClient(URI string, poolName string) (Client, error) {
 
 // Close closes the client's libvirt connection.
 func (client *libvirtClient) Close() error {
-	glog.Infof("Freeing the client pool")
-	err := client.pool.Free()
-	if err != nil {
-		glog.Infof("Error freeing the client pool: %v", err)
-	}
-
 	glog.Infof("Closing libvirt connection: %p", client.connection)
-	remainingRefs, err := client.connection.Close()
+
+	_, err := client.connection.Close()
 	if err != nil {
 		glog.Infof("Error closing libvirt connection: %v", err)
 	}
-	if remainingRefs != 0 {
-		glog.Warningf("libvirt connection %p was not closed, some objects are still holding references to it", client.connection)
-	}
 
 	return err
 }
@@ -195,7 +187,6 @@ func (client *libvirtClient) CreateDomain(input CreateDomainInput) error {
 	if err != nil {
 		return fmt.Errorf("can't retrieve volume %s for pool %s: %v", input.VolumeName, client.poolName, err)
 	}
-	defer diskVolume.Free()
 	if err := setDisks(&domainDef, diskVolume); err != nil {
 		return fmt.Errorf("Failed to setDisks: %s", err)
 	}
@@ -206,6 +197,7 @@ func (client *libvirtClient) CreateDomain(input CreateDomainInput) error {
 	if err != nil {
 		return fmt.Errorf("Error retrieving host architecture: %s", err)
 	}
+
 	if input.Ignition != nil {
 		if err := setIgnition(&domainDef, client, input.Ignition, input.KubeClient, input.MachineNamespace, input.IgnitionVolumeName, arch); err != nil {
 			return err
@@ -215,7 +207,6 @@ func (client *libvirtClient) CreateDomain(input CreateDomainInput) error {
 		if err != nil {
 			return fmt.Errorf("error getting ignition volume: %v", err)
 		}
-		defer ignVolume.Free()
 		ignVolumePath, err := ignVolume.GetPath()
 		if err != nil {
 			return fmt.Errorf("error getting ignition volume path: %v", err)
@@ -387,7 +378,6 @@ func (client *libvirtClient) CreateVolume(input CreateVolumeInput) error {
 
 	volume, err := client.getVolume(input.VolumeName)
 	if err == nil {
-		volume.Free()
 		return fmt.Errorf("storage volume '%s' already exists", input.VolumeName)
 	}
 
@@ -420,7 +410,6 @@ func (client *libvirtClient) CreateVolume(input CreateVolumeInput) error {
 		if err != nil {
 			return fmt.Errorf("Can't retrieve volume %s", input.BaseVolumeName)
 		}
-		defer baseVolume.Free()
 		var baseVolumeInfo *libvirt.StorageVolInfo
 		baseVolumeInfo, err = baseVolume.GetInfo()
 		if err != nil {
@@ -567,7 +556,6 @@ func (client *libvirtClient) GetDHCPLeasesByNetwork(networkName string) ([]libvi
 		glog.Errorf("Failed to fetch network %s from the libvirt", networkName)
 		return nil, err
 	}
-	defer network.Free()
 
 	return network.GetDHCPLeases()
 }
